@@ -100,7 +100,7 @@ def library_base_logger(library_name: str):
 
 
 def aux_library_logger(in_name: str):
-    return logging.getLogger(__name__)
+    return logging.getLogger(in_name)
 
 # def main_logger(in_file_name, in_level, in_back_up=2):
 
@@ -143,6 +143,10 @@ class CustomFormatter(logging.Formatter):
 
         return super().format(record)
 
+    def formatException(self, ei) -> str:
+        output = super().formatException(ei)
+        return '--'.join(output.splitlines())
+
 
 class ExcludeProfilingStreamHandler(logging.StreamHandler):
 
